Crate ordered_hash_map
source ·Expand description
This crate offers an ordered hash map. A structure with the performance characteristics of a HashMap but where the order of insertion is preserved. Exposes a std::HashMap like API but where iterators all operate in insertion order.
Modules
- An Ordered Map implementation
Structs
- A hash map which preserved the order of insertion.