[−][src]Struct ordered_map::OrderedMap
An OrderedMap is like a std::collections::HashMap,
but it is sorted according to the value in descending order.
It doesn't require the value of the map, V, to be comparable,
the comparision of the value is done on C,
which is the return value of extract_comparable(&V).
Methods
impl<'a, K: 'a, V: 'a, C: 'a> OrderedMap<K, V, C> where
K: Eq + Hash + Copy,
C: PartialOrd, [src]
K: Eq + Hash + Copy,
C: PartialOrd,
pub fn new(extract_comparable: fn(_: &V) -> C) -> Self[src]
The function extract_comparable is used to convert the value of type &V
to something comparable of type C
pub fn len(&self) -> usize[src]
pub fn descending_keys(&'a self) -> DescendingKeys<'a, K, C>[src]
Keys of this map in descending order
pub fn descending_values(&'a self) -> DescendingValues<'a, K, V, C>[src]
Values of this map in descending order
pub fn descending_items(&'a self) -> DescendingItems<'a, K, V, C>[src]
(K, V) pairs of this map in descending order
pub fn insert(&mut self, k: K, v: V) -> Option<V>[src]
Insert a new key-value pair to the map,
the old value is returned as Option<V>
pub fn remove(&mut self, k: &K) -> Option<V>[src]
Remove a key-value pair from the map